@@ -29,6 +29,8 @@
 #include "baumbrl.h"
 #include "alvabrl.h"
 #include "handybrl.h"
+#include "ecobrl.h"
+
 #ifdef BRLTTY_SUPPORT
 #include "ttybrl.h"
 #endif
@@ -60,7 +62,10 @@ BRLDevInfo   supported_devices[] = {
   {"HTBS8",   "HandyTech Braille Star 80"},
   {"HTMB2",   "HandyTech Modular 24"},
   {"HTMB4",   "HandyTech Modular 44"},
-  {"HTMB8",   "HandyTech Modular 84"}
+  {"HTMB8",   "HandyTech Modular 84"},
+  {"ECO20",   "EcoBraille 20"},
+  {"ECO40",   "EcoBraille 40"},
+  {"ECO80",   "EcoBraille 80"}
 
  };
 
@@ -172,6 +177,12 @@ brl_open_device (gchar        *device_name,
 	{
 	    rv =  handy_brl_open_device(device_name, port, device_callback, current_device);
 	}
+	else if (strcmp("ECO20", device_name) == 0 ||
+		 strcmp("ECO40", device_name) == 0 ||
+		 strcmp("ECO80", device_name) == 0 )
+	{
+	    rv =  eco_brl_open_device(device_name, port, device_callback, current_device);
+	}
 
 	else
 	{
