@@ -370,7 +370,7 @@ brlui_settings_response_braille_device (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -529,7 +529,7 @@ brlui_translation_table_changeing (Braille *braille_setting)
 
     for (l_iter = 0 ; trans_table_list [ l_iter ].state ; l_iter++)
     {
-	if (!strcmp (key, trans_table_list [ l_iter ].state))
+	if (!strcmp (key, _(trans_table_list [ l_iter ].state)))
 	{
 	    g_free (braille_setting->translation_table);
 	    braille_setting->translation_table = g_strdup (trans_table_list [ l_iter ].file_name);
@@ -588,7 +588,7 @@ brlui_settings_response_translation_table ( GtkDialog *dialog,
 
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -681,7 +681,7 @@ brlui_settings_response_braille_style ( GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -772,7 +772,7 @@ brlui_settings_response_cursor_settings (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -872,7 +872,7 @@ brlui_settings_response_attribute_settings (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -1006,7 +1006,7 @@ brlui_settings_response_braille_fill_char ( GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -1111,7 +1111,7 @@ brlui_settings_response_status_cell (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -1338,7 +1338,7 @@ brlui_response_add_modify_event (GtkDialog *dialog,
 {
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
 
@@ -1592,7 +1592,7 @@ brlui_settings_response_braille_key_mapping (GtkDialog *dialog,
     
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-braille-settings");
+	gn_load_help ("gnopernicus-braille-prefs");
 	return;
     }
     
