@@ -69,7 +69,7 @@ kbui_settings_response (GtkDialog *dialog,
     else
     if (response_id == GTK_RESPONSE_HELP)
     {
-	gn_load_help ("gnopernicus-keyboard-and-mouse-settings");
+	gn_load_help ("gnopernicus-mouse-prefs");
     }
     else	
 	gtk_widget_hide ((GtkWidget*)dialog);
