@@ -1579,7 +1579,8 @@ srl_event_is_reported (SRLEvent *event)
 	    srl_last_create = event->acc_ev->source;
 	    Accessible_ref (srl_last_create);
 	}
-	else
+	else if (srle_has_type (event, SRL_EVENT_WINDOW_ACTIVATE) ||
+	    srle_has_type (event, SRL_EVENT_WINDOW_RESTORE))
 	{
 	    if (srl_last_create == event->acc_ev->source)
 		rv = FALSE;
